@@ -7,7 +7,7 @@ from tasq_cli.utils import get_config_directory, get_config_file_path, get_crede
 KB = 1024
 MB = KB * 1024
 
-VERSION = '1.0.14'
+VERSION = '1.0.16'
 
 # ---
 # Logging
@@ -58,7 +58,10 @@ CLIENT_ID = creds['client_id']
 BUCKET = creds['bucket_name']
 ACCESS_KEY = creds['access_key']
 SECRET_KEY = creds['secret_key']
+TOKEN = creds['token']
 
+#SERVER = 'http://localhost:8000/api/v2'
+SERVER = 'https://console.tasq.ai/api/v2'
 
 # ---
 # Settings
